#
# spec file for package python-pyqtgraph
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%bcond_without  test
%define skip_python2 1
%define skip_python36 1
# check pyqtgraph/tests/image_testing.py for the current tag
%define testdatatag test-data-8
Name:           python-pyqtgraph
Version:        0.12.2
Release:        1.1
Summary:        Scientific Graphics and GUI Library for Python
License:        MIT
Group:          Development/Languages/Python
URL:            http://www.pyqtgraph.org/
Source:         https://files.pythonhosted.org/packages/source/p/pyqtgraph/pyqtgraph-%{version}.tar.gz
Source1:        https://github.com/pyqtgraph/test-data/archive/%{testdatatag}.tar.gz
BuildRequires:  %{python_module numpy >= 1.17}
BuildRequires:  %{python_module qt5 >= 5.12}
BuildRequires:  %{python_module setuptools}
BuildRequires:  dos2unix
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  python3-Sphinx
%if %{with test}
BuildRequires:  %{python_module h5py}
BuildRequires:  %{python_module matplotlib-qt5}
BuildRequires:  %{python_module matplotlib}
BuildRequires:  %{python_module opengl}
BuildRequires:  %{python_module pytest-xdist}
BuildRequires:  %{python_module pytest-xvfb}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module scipy}
BuildRequires:  git-core
%endif
Requires:       python-numpy >= 1.17
Requires:       python-qt5 >= 5.12
Recommends:     python-colorcet
Recommends:     python-cupy
Recommends:     python-h5py
Recommends:     python-numba
Recommends:     python-opengl
Recommends:     python-scipy
BuildArch:      noarch

%python_subpackages

%description
A pure-Python graphics library for PyQt/PySide/PyQt5/PySide2

PyQtGraph is intended for use in mathematics / scientific / engineering
applications. It is written in pure python, but the library leverages
numpy for number crunching, Qt's GraphicsView framework for 2D display,
and OpenGL for 3D display.

%package -n %{name}-doc
Summary:        Documentation for %{name}
Group:          Development/Languages/Python
Provides:       %{python_module %{name} = %{version}}

%description -n %{name}-doc
Documentation and help files for %{name}

%prep
%setup -q -n pyqtgraph-%{version}
chmod a+x examples/*.py
%if %{with test}
# For local builds: Delete files from previous failed builds, if any.
# The next version allows us to install test data into a custom
# $GITHUB_WORKSPACE directory inside the autocleaned BUILD dir instead of ~.
rm -rf ~/.pyqtgraph/test-data
mkdir -p ~/.pyqtgraph/test-data
pushd ~/.pyqtgraph/test-data
tar -x --strip-components=2 -f %{SOURCE1}
git init
git config user.email "abuild@obs.local"
git config user.name "abuild"
git add .
git commit -m "testing on openSUSE"
git tag %{testdatatag}
popd
%endif

%build
%python_build

%install
%python_install

pushd doc
make html
rm build/html/.buildinfo build/doctrees/environment.pickle
popd

mkdir -p %{buildroot}%{_docdir}/%{name}/
cp -r doc/build/html %{buildroot}%{_docdir}/%{name}/
cp -r doc/build/doctrees %{buildroot}%{_docdir}/%{name}/
cp -r examples %{buildroot}%{_docdir}/%{name}/

for f in MultiPlotSpeedTest MultiPlotWidget PlotSpeedTest ROItypes ScatterPlotSpeedTest ViewBox infiniteline_performance ; do
    %{python_expand chmod a+x %{buildroot}%{$python_sitelib}/pyqtgraph/examples/$f.py
    sed -i "s|^#!/usr/bin/env python$|#!%__$python|" %{buildroot}%{$python_sitelib}/pyqtgraph/examples/$f.py
    sed -i "s|^#!/usr/bin/python$|#!%__$python|" %{buildroot}%{$python_sitelib}/pyqtgraph/examples/$f.py
    sed -i "s|^#!/usr/bin/python -i$|#!%__$python|" %{buildroot}%{$python_sitelib}/pyqtgraph/examples/$f.py
    }
    sed -i "s|^#!/usr/bin/env python$|#!%__python3|" %{buildroot}%{_docdir}/%{name}/examples/$f.py
    sed -i "s|^#!/usr/bin/python$|#!%__python3|" %{buildroot}%{_docdir}/%{name}/examples/$f.py
    sed -i "s|^#!/usr/bin/python -i$|#!%__python3|" %{buildroot}%{_docdir}/%{name}/examples/$f.py
done
%python_compileall
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%fdupes %{buildroot}%{_docdir}/%{name}/

%if %{with test}
%check
# these tests need reference images audited by a user with GUI
donttest+=" or test_ImageItem or test_PlotCurveItem"
donttest+=" or test_ROI and (test_getArrayRegion or test_PolyLineROI)"
# reload happens but is not detected
donttest+=" or test_reload"
%pytest -ra -n auto -k "not (${donttest:4})"
rm -r ~/.pyqtgraph
%endif

%files %{python_files}
%license LICENSE.txt
%exclude %{_docdir}/%{name}/doctrees/
%exclude %{_docdir}/%{name}/examples/
%exclude %{_docdir}/%{name}/html/
%{python_sitelib}/pyqtgraph/
%{python_sitelib}/pyqtgraph-%{version}-py*.egg-info

%files -n %{name}-doc
%license LICENSE.txt
%doc %dir %{_docdir}/%{name}/
%doc %{_docdir}/%{name}/doctrees/
%doc %{_docdir}/%{name}/examples/
%doc %{_docdir}/%{name}/html/

%changelog
* Mon Aug 30 2021 Fusion Future <qydwhotmail@gmail.com>
- Update to 0.12.2:
  * Qt6 6.0 support has been removed in favor of Qt6 6.1+
  * More numba utilization, specifically for makeARGB
  * Substantial ImageItem performance improvements have been made
  * Significant performance improvements made to ScatterPlotItem
    and LinePlots
  * More ColorMap features/support
- Changes since 0.12.0:
  * Qt < 5.12, Python < 3.7, and NumPy < 1.17 are no longer
    supported.
  * For full changelog (huge) since 0.12.0 see
    https://github.com/pyqtgraph/pyqtgraph/blob/master/CHANGELOG
- Update test data version to 8.
* Thu Feb 11 2021 Ben Greiner <code@bnavigator.de>
- Update to version 0.11.1
  * For full changelog (huge) since 0.10.0 see
    https://github.com/pyqtgraph/pyqtgraph/blob/master/CHANGELOG
  * 0.11 is the last feature release to support Python 2 and PyQt4
  * PySide2 support
- Enable test suite with test data
  * construct git repo from test-data-7.tar.gz
- Project adopted NEP 29 for next release. Drop python36 build
  now, because there is no python36-{numpy,scipy} in TW anymore.
* Fri May 18 2018 jengelh@inai.de
- Trim bias from description.
* Thu May 17 2018 bwiedemann@suse.com
- Drop environment.pickle from rpm to make build reproducible
* Wed May  9 2018 toddrme2178@gmail.com
- Use license tag
* Tue Aug 22 2017 toddrme2178@gmail.com
- Implement single-spec version
- Fix rpmlint issues
- Fix shebangs
* Mon Nov  7 2016 termim@gmail.com
- Update to 0.10.0
  * New Features:
  - PyQt5 support
  - Options for interpreting image data as either row-major or col-major
  - InfiniteLine and LinearRegionItem can have attached labels
  - DockArea:
  - Dock titles can be changed after creation
  - Added Dock.sigClosed
  - Added TextItem.setColor()
  - FillBetweenItem supports finite-connected curves (those that exclude
    nan/inf)
  * API / behavior changes:
  - Improved ImageItem performance for some data types by scaling LUT
    instead of image
  - Change the defaut color kwarg to None in TextItem.setText() to avoid
    changing the color every time the text is changed.
  - FFT plots skip first sample if x-axis uses log scaling
  - Multiprocessing system adds bytes and unicode to the default list of
    no-proxy data types
  - Version number scheme changed to be PEP440-compliant (only affects
    installations from non-release git commits)
  * Bugfixes:
  - Fix for numpy API change that caused casting errors for inplace operations
  - Fixed git version string generation on python3
  - Fixed setting default values for out-of-bound points in
    pg.interpolateArray
  - Fixed plot downsampling bug on python 3
  - Fixed invalid slice in ImageItem.getHistogram
  - DockArea:
  - Fixed adding Docks to DockArea after all Docks have been removed
  - Fixed DockArea save/restoreState when area is empty
  - Properly remove select box when export dialog is closed using window
    decorations
  - Remove all modifications to python builtins
  - Better Python 2.6 compatibility
  - Fix SpinBox decimals
  - Fixed numerous issues with ImageItem automatic downsampling
  - Fixed PlotItem average curves using incorrect stepMode
  - Fixed TableWidget eating key events
  - Prevent redundant updating of flowchart nodes with multiple inputs
  - Ignore wheel events in GraphicsView if mouse interaction is disabled
  - Correctly pass calls to QWidget.close() up the inheritance chain
  - ColorMap forces color inputs to be sorted
  - Fixed memory mapping for RemoteGraphicsView in OSX
  - Fixed QPropertyAnimation str/bytes handling
  - Fixed __version__ string update when using `setup.py install` with
    newer setuptools
  * Maintenance:
  - Image comparison system for unit testing plus tests for several
    graphics items
  - Travis CI and coveralls/codecov support
  - Add examples to unit tests
* Fri Dec 11 2015 mardnh@gmx.de
- Update to version 0.9.10
  * No changelog available
* Sun Nov 24 2013 p.drouand@gmail.com
- Update to version 0.9.8
  + No changelog available
- Remove useless CFLAGS definition
- README.txt is not provided anymore by upstream
* Sat Apr 20 2013 toddrme2178@gmail.com
- Remove unneeded python(abi) requires
* Thu Apr 18 2013 toddrme2178@gmail.com
- Update to 0.9.7
  * No changelog
- Add python 3 version
* Thu Nov 29 2012 toddrme2178@gmail.com
- Initial spec file
